@@ -20,8 +20,7 @@
 #include <QFile>
 #include <QTime>
 #include <QFileInfo>
-#include <QRegExp>
-#include <QTextCodec>
+#include <QRegularExpression>
 #include <QList>
 #include <QTextStream>
 #include <QEventLoop>
@@ -37,10 +36,21 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
 
     // find codec for file
     //    bool hadCodec;
-    QTextCodec* codec = codecForDevice(device/*, &hadCodec*/);
+    const auto codecName = codecForDevice(device/*, &hadCodec*/);
     QTextStream stream(device);
     stream.seek(0);
-    stream.setCodec(codec);
+
+    const auto encoding = QStringConverter::encodingForName(codecName.constData());
+    QString decodedData;
+    if (encoding) {
+        stream.setEncoding(*encoding);
+    } else {
+        // non-UTF encoding not supported by QTextStream directly anymore
+        QStringDecoder decoder(codecName.constData());
+        device->seek(0);
+        decodedData = decoder.decode(device->readAll());
+        stream.setString(&decodedData, QIODevice::ReadOnly);
+    }
 
     //QIODevice *dev = stream.device();
     //int fileSize = dev->size();
@@ -172,7 +182,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
     setHeader(tempHeader);
     setCatalogExtraData(_extraDataSaver.extraData);
     setErrorIndex(errorIndex);
-    setCodec(codec);
+    setCodec(codecName);
     //setMimeTypes( "text/x-gettext-translation" );
 #if 0
     if (Q_UNLIKELY(recoveredErrorInHeader)) {
@@ -189,33 +199,33 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
     }
 }
 
-QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCodec*/)
+QByteArray GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCodec*/)
 {
     QTextStream stream(device);
     stream.seek(0);
     _errorLine = 0;
-    stream.setCodec("UTF-8");
-    stream.setAutoDetectUnicode(true); //this way we can
-    QTextCodec* codec = stream.codec(); //detect UTF-16
+    stream.setEncoding(QStringConverter::Utf8);
+    stream.setAutoDetectUnicode(true); //this way we can detect UTF-16
 
     ConversionStatus status = readEntry(stream);
     if (Q_UNLIKELY(status != OK && status != RECOVERED_PARSE_ERROR)) {
         qCDebug(LOKALIZE_LOG) << "wasn't able to read header";
-        return codec;
+        return QStringConverter::nameForEncoding(stream.encoding());
     }
 
-    QRegExp regexp(QStringLiteral("Content-Type:\\s*\\w+/[-\\w]+;?\\s*charset\\s*=\\s*(\\S+)\\s*\\\\n"));
-    if (regexp.indexIn(_msgstr.first()) == -1) {
+    const QRegularExpression regexp(QStringLiteral("Content-Type:\\s*\\w+/[-\\w]+;?\\s*charset\\s*=\\s*(\\S+)\\s*\\\\n"));
+    const auto match = regexp.match(_msgstr.first());
+    if (!match.hasMatch()) {
         qCDebug(LOKALIZE_LOG) << "no charset entry found";
-        return codec;
+        return QStringConverter::nameForEncoding(stream.encoding());
     }
 
-    const QString charset = regexp.cap(1);
+    const QString charset = match.captured(1);
     if (charset != QLatin1String("UTF-8")) qCDebug(LOKALIZE_LOG) << "charset:" << charset;
 
     if (charset.isEmpty()) {
         qCWarning(LOKALIZE_LOG) << "No charset defined! Assuming UTF-8!";
-        return codec;
+        return QStringConverter::nameForEncoding(stream.encoding());
     }
 
     // "CHARSET" is the default charset entry in a template (pot).
@@ -223,18 +233,15 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
     // at least utf8, so utf8-codec can be used for both.
     if (charset.contains(QLatin1String("CHARSET"))) {
         qCDebug(LOKALIZE_LOG) << "file seems to be a template: using utf-8 encoding.";
-        return QTextCodec::codecForName("utf8");;
+        return "utf-8";
     }
 
-    QTextCodec* t = nullptr;
-    t = QTextCodec::codecForName(charset.toLatin1());
-
-    if (t)
-        return t;
+    if (QStringDecoder t(charset.toLatin1().constData()); t.isValid())
+        return t.name();
     else
         qCWarning(LOKALIZE_LOG) << "charset found, but no codec available, using UTF-8 instead";
 
-    return codec;//UTF-8
+    return QStringConverter::nameForEncoding(stream.encoding());
 }
 
 ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
@@ -253,7 +260,6 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
     //qCDebug(LOKALIZE_LOG) << " START";
     enum {Begin, Comment, Msgctxt, Msgid, Msgstr} part = Begin;
 
-    _trailingNewLines = 0;
     bool error = false;
     bool recoverableError = false;
     //bool seenMsgctxt=false;
@@ -294,13 +300,8 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 
         // remember wrapping state to save file nicely
         int len = line.length();
-        if (len) {
-            _trailingNewLines = 0;
-            if (_maxLineLength < len && line.at(0) != QLatin1Char('#'))
+        if (len && _maxLineLength < len && line.at(0) != QLatin1Char('#'))
                 _maxLineLength = len;
-        } else
-            ++_trailingNewLines;
-
 
         if (part == Begin) {
             // ignore trailing newlines
@@ -318,7 +319,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgctxt;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgctxt\\s*\"")));
+                line.remove(QRegularExpression(QStringLiteral("^msgctxt\\s*\"")));
                 line.remove(_rxMsgLineRemEndQuote);
                 _msgctxt = line;
                 _msgctxtPresent = true;
@@ -339,7 +340,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgid\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgid\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgidMultiline = line.isEmpty();
@@ -364,7 +365,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgctxt;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgctxt\\s*\"")));
+                line.remove(QRegularExpression(QStringLiteral("^msgctxt\\s*\"")));
                 line.remove(_rxMsgLineRemEndQuote);
                 _msgctxt = line;
                 _msgctxtPresent = true;
@@ -384,7 +385,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgid\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgid\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgidMultiline = line.isEmpty();
@@ -426,7 +427,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgid\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgid\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgidMultiline = line.isEmpty();
@@ -464,7 +465,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 _gettextPluralForm = true;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgid_plural\\s*\"")));
+                line.remove(QRegularExpression(QStringLiteral("^msgid_plural\\s*\"")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgid.append(line);
@@ -475,7 +476,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 _gettextPluralForm = true;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgid_plural\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgid_plural\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgid.append(line);
@@ -507,7 +508,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgstr;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgstr\\[0\\]\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgstr\\[0\\]\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgstrMultiline = line.isEmpty();
@@ -516,7 +517,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgstr;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgstr\\[0\\]\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgstr\\[0\\]\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgstrMultiline = line.isEmpty();
@@ -573,7 +574,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 (*msgstrIt) += line;
             } else if (_gettextPluralForm && (line.contains(_rxMsgStrPlural))) {
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgstr\\[[0-9]+\\]\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgstr\\[[0-9]+\\]\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgstr.append(line);
@@ -585,7 +586,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 break;
             } else if (Q_UNLIKELY(/*_testBorked&&*/ _gettextPluralForm && (line.contains(_rxMsgStrPluralBorked)))) {
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp(QStringLiteral("^msgstr\\[[0-9]\\]\\s*\"?")));
+                line.remove(QRegularExpression(QStringLiteral("^msgstr\\[[0-9]\\]\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgstr.append(line);
