@@ -192,6 +192,7 @@ bool TsStorage::save(QIODevice* device, bool belongsToProject)
                .replace(QStringLiteral("<numerusform><![CDATA["), QStringLiteral("<numerusform>"))
                .replace(QStringLiteral("<translation type=\"vanished\"><![CDATA["), QStringLiteral("<translation type=\"vanished\">"))
                .replace(QStringLiteral("<translation type=\"unfinished\"><![CDATA["), QStringLiteral("<translation type=\"unfinished\">"))
+               .replace(QStringLiteral("<translation type=\"obsolete\"><![CDATA["), QStringLiteral("<translation type=\"obsolete\">"))
                .replace(QStringLiteral("<translatorcomment><![CDATA["), QStringLiteral("<translatorcomment>"))
                .replace(QStringLiteral("]]></source>"), QStringLiteral("</source>"))
                .replace(QStringLiteral("]]></translation>"), QStringLiteral("</translation>"))
@@ -421,7 +422,7 @@ QVector<AltTrans> TsStorage::altTrans(const DocPosition& pos) const
 
     QString oldsource = content(unitForPos(pos.entry).firstChildElement(names[OldSourceTag]));
     if (!oldsource.isEmpty())
-        result << AltTrans(CatalogString(oldsource), i18n("Previous source value, saved by lupdate tool"));
+        result << AltTrans(CatalogString(), CatalogString(oldsource), i18n("Previous source value, saved by lupdate tool"));
 
     return result;
 }
