@@ -11,6 +11,7 @@
 #ifndef COMPLETIONSTORAGE_H
 #define COMPLETIONSTORAGE_H
 #include <QMap>
+#include <QRegularExpression>
 #include "catalog.h"
 
 class CompletionStorage
@@ -28,7 +29,7 @@ public:
     QStringList makeCompletion(const QString&) const;
 
 public:
-    QRegExp rxSplit{QStringLiteral("\\W+|\\d+")};
+    QRegularExpression rxSplit{QStringLiteral("\\W+|\\d+")};
 private:
     QMap<QString, int> m_words; //how many occurencies a word has
     //QSet save which files we scanned?
