@@ -82,7 +82,7 @@ EntryFindDialog::EntryFindDialog(QWidget* parent)
     setHasSelection(false);
 
     KConfig config;
-    KConfigGroup stateGroup(&config, "FindReplace");
+    KConfigGroup stateGroup(&config, QStringLiteral("FindReplace"));
     setOptions(stateGroup.readEntry("FindOptions", (qlonglong)0));
     setFindHistory(stateGroup.readEntry("FindHistory", QStringList()));
 }
@@ -90,7 +90,7 @@ EntryFindDialog::EntryFindDialog(QWidget* parent)
 EntryFindDialog::~EntryFindDialog()
 {
     KConfig config;
-    KConfigGroup stateGroup(&config, "FindReplace");
+    KConfigGroup stateGroup(&config, QStringLiteral("FindReplace"));
     stateGroup.writeEntry("FindOptions", (qlonglong)options());
     stateGroup.writeEntry("FindHistory", findHistory());
 
@@ -137,7 +137,7 @@ EntryReplaceDialog::EntryReplaceDialog(QWidget* parent)
     setHasSelection(false);
 
     KConfig config;
-    KConfigGroup stateGroup(&config, "FindReplace");
+    KConfigGroup stateGroup(&config, QStringLiteral("FindReplace"));
     setOptions(stateGroup.readEntry("ReplaceOptions", (qlonglong)0));
     setFindHistory(stateGroup.readEntry("ReplacePatternHistory", QStringList()));
     setReplacementHistory(stateGroup.readEntry("ReplacementHistory", QStringList()));
@@ -146,7 +146,7 @@ EntryReplaceDialog::EntryReplaceDialog(QWidget* parent)
 EntryReplaceDialog::~EntryReplaceDialog()
 {
     KConfig config;
-    KConfigGroup stateGroup(&config, "FindReplace");
+    KConfigGroup stateGroup(&config, QStringLiteral("FindReplace"));
     stateGroup.writeEntry("ReplaceOptions", (qlonglong)options());
     stateGroup.writeEntry("ReplacePatternHistory", findHistory());
     stateGroup.writeEntry("ReplacementHistory", replacementHistory());
@@ -239,7 +239,6 @@ void EditorTab::findNext(const DocPosition& startingPos)
         _searchingPos.offset = 0;
 
 
-    QRegExp rx(QStringLiteral("[^(\\\\n)>]\n"));
     //_searchingPos.part=DocPosition::Source;
     bool ignoreaccels = m_find->options()&IGNOREACCELS;
     bool includenotes = m_find->options()&INCLUDENOTES;
@@ -529,7 +528,6 @@ void EditorTab::spellcheckNext()
         if (!switchNext(m_catalog, _spellcheckPos)) {
             qCDebug(LOKALIZE_LOG) << _spellcheckStartPos.entry;
             qCDebug(LOKALIZE_LOG) << _spellcheckStartPos.form;
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             bool continueFromStart =
                     !(_spellcheckStartPos.entry == 0 && _spellcheckStartPos.form == 0)
                     && KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
@@ -538,12 +536,6 @@ void EditorTab::spellcheckNext()
                         i18nc("@title", "Spellcheck"),
                         KStandardGuiItem::cont(),
                         KStandardGuiItem::cancel());
-#else
-            bool continueFromStart =
-                !(_spellcheckStartPos.entry == 0 && _spellcheckStartPos.form == 0)
-                && KMessageBox::questionYesNo(this, i18n("Lokalize has reached end of document. Do you want to continue from start?"),
-                                              i18nc("@title", "Spellcheck")) == KMessageBox::Yes;
-#endif
             if (continueFromStart) {
                 _spellcheckStartPos.entry = 0;
                 _spellcheckStartPos.form = 0;
@@ -576,7 +568,7 @@ void EditorTab::spellcheckShow(const QString &word, int offset)
 
     QString source = m_catalog->source(_spellcheckPos);
     source.remove(accel);
-    if (source.contains(word) && project.targetLangCode().leftRef(2) != project.sourceLangCode().leftRef(2)) {
+    if (source.contains(word) && QStringView(project.targetLangCode()).left(2) != QStringView(project.sourceLangCode()).left(2)) {
         m_sonnetDialog->setUpdatesEnabled(false);
         m_sonnetChecker->continueChecking();
         return;
