@@ -7,11 +7,14 @@
 #ifndef LANGUAGETOOLPARSER_H
 #define LANGUAGETOOLPARSER_H
 
+#include <QString>
+#include <QJsonObject>
+
 class LanguageToolParser
 {
 public:
-    LanguageToolParser();
-    ~LanguageToolParser();
+    LanguageToolParser() = default;
+    ~LanguageToolParser() = default;
     QString parseResult(const QJsonObject &obj, const QString &text) const;
 };
 
