@@ -443,12 +443,12 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         //qCWarning(LOKALIZE_LOG)<<"offset"<<offset<<"charsRemoved"<<charsRemoved<<"_oldMsgstr"<<_oldMsgstr;
 
         QString target = m_catalog->targetWithTags(pos).string;
-        const QStringRef addedText = editText.midRef(offset, charsAdded);
+        const auto addedText = QStringView(editText).mid(offset, charsAdded);
 
 //BEGIN XLIFF markup handling
         //protect from tag removal
         //TODO use midRef when Qt 4.8 is in distros
-        bool markupRemoved = charsRemoved && target.midRef(offset, charsRemoved).contains(TAGRANGE_IMAGE_SYMBOL);
+        bool markupRemoved = charsRemoved && QStringView(target).mid(offset, charsRemoved).contains(TAGRANGE_IMAGE_SYMBOL);
         bool markupAdded = charsAdded && addedText.contains(TAGRANGE_IMAGE_SYMBOL);
         if (markupRemoved || markupAdded) {
             bool modified = false;
@@ -503,7 +503,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         // and for statusbar
         Q_EMIT contentsModified(m_currentPos);
         if (charsAdded == 1) {
-            int sp = CompletionStorage::instance()->rxSplit.lastIndexIn(target, offset - 1);
+            auto sp = target.lastIndexOf(CompletionStorage::instance()->rxSplit, offset - 1);
             int len = (offset - sp);
             int wordCompletionLength = Settings::self()->wordCompletionLength();
             if (wordCompletionLength >= 3 && len >= wordCompletionLength)
@@ -605,7 +605,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             QByteArray a;
             QDataStream out(&a, QIODevice::WriteOnly);
             QVariant v;
-            v.setValue<CatalogString>(catalogString);
+            v.setValue(catalogString);
             out << v;
             mimeData->setData(LOKALIZE_XLIFF_MIMETYPE, a);
         }
@@ -634,9 +634,9 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
     void TranslationUnitTextEdit::dropEvent(QDropEvent * event) {
         //Ensure the cursor moves to the correct location
         if (m_part == DocPosition::Target) {
-            setTextCursor(cursorForPosition(event->pos()));
+            setTextCursor(cursorForPosition(event->position().toPoint()));
             //This is a copy modifier, disable the selection flags
-            if (event->keyboardModifiers() & Qt::ControlModifier) {
+            if (event->modifiers() & Qt::ControlModifier) {
                 m_cursorSelectionEnd = 0;
                 m_cursorSelectionStart = 0;
             }
@@ -818,7 +818,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
                         && !isMasked(str, pos - 1))
                         ins = QLatin1Char('\\');
                     // if there is no new line at the end
-                    if (pos < 2 || str.midRef(pos - 2, 2) != QLatin1String("\\n"))
+                    if (pos < 2 || QStringView(str).mid(pos - 2, 2) != QLatin1String("\\n"))
                         ins += QLatin1Char(' ');
                 } else if (str.isEmpty()) {
                     ins = QStringLiteral("\\n");
@@ -1060,7 +1060,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             else
                 Q_EMIT gotoNextUntranslatedRequested();
             break;
-        case Qt::ControlModifier + Qt::ShiftModifier:
+        case Qt::ControlModifier | Qt::ShiftModifier:
             if (event->angleDelta().y() > 0)
                 Q_EMIT gotoPrevFuzzyUntrRequested();
             else
@@ -1191,8 +1191,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
                 return;
 
             //QRegExp tag("(<[^>]*>)+|\\&\\w+\\;");
-            QRegExp tag(Project::instance()->markup());
-            tag.setMinimal(true);
+            const QRegularExpression tag(Project::instance()->markup(), QRegularExpression::InvertedGreedinessOption);
             QString en = m_catalog->sourceWithTags(m_currentPos).string;
             QString target(toPlainText());
             en.remove(QLatin1Char('\n'));
@@ -1200,20 +1199,25 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             int pos = 0;
             //tag.indexIn(en);
             int posInMsgStr = 0;
-            while ((pos = tag.indexIn(en, pos)) != -1) {
+            while (true) {
+                const auto match = tag.match(en, pos);
+                if (!match.hasMatch()) {
+                    break;
+                }
+                pos = match.capturedStart();
                 /*        QString str(tag.cap(0));
                         str.replace("&","&&");*/
-                txt = menu.addAction(tag.cap(0));
-                pos += tag.matchedLength();
+                txt = menu.addAction(match.captured(0));
+                pos += match.capturedLength();
 
-                if (posInMsgStr != -1 && (posInMsgStr = target.indexOf(tag.cap(0), posInMsgStr)) == -1) {
+                if (posInMsgStr != -1 && (posInMsgStr = target.indexOf(match.captured(0), posInMsgStr)) == -1) {
                     if (immediate) {
                         insertPlainTextWithCursorCheck(txt->text());
                         return;
                     }
                     menu.setActiveAction(txt);
                 } else if (posInMsgStr != -1)
-                    posInMsgStr += tag.matchedLength();
+                    posInMsgStr += match.capturedLength();
             }
             if (!txt || immediate)
                 return;
@@ -1231,7 +1235,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         QString text = sourceWithTags.string;
         QString out;
         QString ctxt = m_catalog->context(DocPosition(m_currentPos.entry)).first();
-        QRegExp delimiter(QStringLiteral("\\s*,\\s*"));
+        const QRegularExpression delimiter(QStringLiteral("\\s*,\\s*"));
 
         //TODO ask for the fillment if the first time.
         //BEGIN KDE specific part
@@ -1305,7 +1309,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
 
     void TranslationUnitTextEdit::doCompletion(int pos) {
         QString target = m_catalog->targetWithTags(m_currentPos).string;
-        int sp = CompletionStorage::instance()->rxSplit.lastIndexIn(target, pos - 1);
+        auto sp = target.lastIndexOf(CompletionStorage::instance()->rxSplit, pos - 1);
         int len = (pos - sp) - 1;
 
         QStringList s = CompletionStorage::instance()->makeCompletion(QString::fromRawData(target.unicode() + sp + 1, len));
